@@ -20,7 +20,7 @@ from torchmetrics import Metric
 
 from composer.metrics import METRIC_DEFAULT_CTORS, InContextLearningMetric
 from composer.models.base import ComposerModel
-from composer.utils import MissingConditionalImportError, get_file, import_object
+from composer.utils import MissingConditionalImportError, get_file, import_object, safe_torch_load
 
 if TYPE_CHECKING:
     import transformers
@@ -46,6 +46,7 @@ class HuggingFaceModel(ComposerModel):
         metrics (list[Metric], optional): list of torchmetrics to apply to the output of `eval_forward` during training. If ``eval_metrics`` is ``None``, these will also be used as ``eval_metrics``.  Default: ``None``.
         eval_metrics (list[Metric], optional): list of torchmetrics to compute on the eval_dataloader, or be accessible to :class:`Evaluator`s. Default: ``None``.
         shift_labels (bool, optional): If True, the batch's labels will be shifted before being used to calculate metrics. This should be set to true for CausalLM models and false otherwise. If not specified, `shift_labels` will be set automatically based on the model class name. Default: ``None``.
+        allow_embedding_resizing (bool, optional): If True, the model's embeddings will be automatically resized when they are smaller than the tokenizer vocab size. Default: ``False``.
 
         .. note:: To ensure correct behavior, set `shift_labels` manually if using a custom model (i.e., if `model` is not
         an instance of a registered 🤗 Transformers class).
@@ -70,7 +71,8 @@ class HuggingFaceModel(ComposerModel):
                  use_logits: Optional[bool] = False,
                  metrics: Optional[List[Metric]] = None,
                  eval_metrics: Optional[List[Metric]] = None,
-                 shift_labels: Optional[bool] = None) -> None:
+                 shift_labels: Optional[bool] = None,
+                 allow_embedding_resizing: bool = False) -> None:
         try:
             import transformers
             del transformers  # unused
@@ -89,11 +91,30 @@ class HuggingFaceModel(ComposerModel):
             log.warning(
                 'The tokenizer was not provided. This means the tokenizer config will not be saved in the checkpoint.')
 
-        if tokenizer is not None and self.config.vocab_size != len(tokenizer):
-            # set model's word embedding matrix and final lm_head to vocab size according to tokenizer
-            log.warning(f'The number of tokens in the tokenizer and the number of tokens in the model are different.'
-                        f' Resizing the model tokenizer to {len(tokenizer)} from {self.config.vocab_size}.')
-            self.model.resize_token_embeddings(len(tokenizer))
+        if tokenizer is not None and self.config.vocab_size < len(tokenizer):
+            if allow_embedding_resizing:
+                # when the embedding size is smaller than the tokenizer vocab size,
+                # the embeddings should get resized to match the tokenizer vocab size
+                log.warning(f'The number of tokens in the tokenizer is greater than the number of tokens in the model.'
+                            f' This would cause an error during training.'
+                            f' Resizing the model embeddings to {len(tokenizer)} from {self.config.vocab_size}.')
+                self.model.resize_token_embeddings(len(tokenizer))
+            else:
+                raise ValueError(
+                    f'The number of tokens in the tokenizer is greater than the number of tokens in the model.'
+                    f' This would cause an error during training.'
+                    f' You can resize the model embeddings to {len(tokenizer)} from {self.config.vocab_size}'
+                    f' by calling `model.resize_token_embeddings(len(tokenizer))` before calling the `HuggingFaceModel`'
+                    f' constructor, or pass `allow_embedding_resizing=True` to have it done automatically.')
+        elif tokenizer is not None and self.config.vocab_size > len(tokenizer):
+            # when the embedding size is greater than the tokenizer vocab size,
+            # the embeddings do not _need_ to be resized to match the tokenizer vocab size,
+            # and should be done by the user if desired
+            log.warning(
+                f'The number of tokens in the tokenizer is less than the number of tokens in the model.'
+                f' You may want to resize the model embeddings to {len(tokenizer)} from {self.config.vocab_size}'
+                f' by calling `model.resize_token_embeddings(len(tokenizer))` before calling the `HuggingFaceModel`'
+                f' constructor.')
 
         self.use_logits = use_logits
 
@@ -205,7 +226,7 @@ class HuggingFaceModel(ComposerModel):
         get_file(checkpoint_path, str(local_checkpoint_save_location))
 
         # load the state dict in
-        loaded_state_dict = torch.load(local_checkpoint_save_location, map_location='cpu')
+        loaded_state_dict = safe_torch_load(local_checkpoint_save_location)
 
         hf_state = loaded_state_dict['state']['integrations']['huggingface']
         hf_model_state = hf_state['model']
@@ -501,7 +522,7 @@ def write_huggingface_pretrained_from_composer_checkpoint(
     # download the checkpoint file
     get_file(str(checkpoint_path), str(local_checkpoint_save_location))
 
-    composer_state_dict = torch.load(local_checkpoint_save_location, map_location='cpu')
+    composer_state_dict = safe_torch_load(local_checkpoint_save_location)
 
     config = get_hf_config_from_composer_state_dict(composer_state_dict)
     config.save_pretrained(output_folder)
