@@ -10,7 +10,7 @@ from typing import List, Optional
 import torchvision
 from packaging import version
 from torchmetrics import MetricCollection
-from torchmetrics.classification import Accuracy
+from torchmetrics.classification import MulticlassAccuracy
 from torchvision.models import resnet
 
 from composer.loss import loss_registry
@@ -112,8 +112,8 @@ def composer_resnet(model_name: str,
     loss_fn = loss_registry[loss_name]
 
     # Create metrics for train and validation
-    train_metrics = Accuracy()
-    val_metrics = MetricCollection([CrossEntropy(), Accuracy()])
+    train_metrics = MulticlassAccuracy(num_classes=num_classes, average='micro')
+    val_metrics = MetricCollection([CrossEntropy(), MulticlassAccuracy(num_classes=num_classes, average='micro')])
 
     # Apply Initializers to model
     for initializer in initializers:
