@@ -136,7 +136,8 @@ def prepare_fsdp_module(model: torch.nn.Module, optimizers: Optional[Union[torch
     """
     if version.parse(torch.__version__) < version.parse('1.13.0'):
         raise RuntimeError('To use FSDP with Composer, you must use torch>=1.13.0.')
-    from torch.distributed.algorithms._checkpoint.checkpoint_wrapper import (apply_activation_checkpointing,
+    from torch.distributed.algorithms._checkpoint.checkpoint_wrapper import (CheckpointImpl,
+                                                                             apply_activation_checkpointing,
                                                                              checkpoint_wrapper)
     from torch.distributed.fsdp import FullyShardedDataParallel
     from torch.distributed.fsdp.flatten_params_wrapper import FlattenParamsWrapper
@@ -195,6 +196,7 @@ def prepare_fsdp_module(model: torch.nn.Module, optimizers: Optional[Union[torch
     limit_all_gathers = fsdp_config.get('limit_all_gathers', False)
     ignored_modules = fsdp_config.get('ignored_modules', None)
     state_dict_type = fsdp_config.get('state_dict_type', 'full')
+    activation_checkpointing_reentrant = fsdp_config.get('activation_checkpointing_reentrant', True)
 
     # We choose to not wrap the ComposerModel directly, but instead wrap any submodules like `ComposerModel.model`
     # This makes it safer to call ComposerModel-specific functions like 'eval_forward' that
@@ -303,9 +305,21 @@ def prepare_fsdp_module(model: torch.nn.Module, optimizers: Optional[Union[torch
 
             # Activation Checkpointing
             if activation_checkpointing or activation_cpu_offload:
-                first_wrap_fn = checkpoint_wrapper if activation_checkpointing else (lambda module: module)
-                second_wrap_fn = (lambda module: checkpoint_wrapper(first_wrap_fn(module), offload_to_cpu=True)
-                                 ) if activation_cpu_offload else first_wrap_fn
+                if not activation_checkpointing_reentrant:
+                    first_wrap_fn = lambda m: checkpoint_wrapper(m, checkpoint_impl=CheckpointImpl.NO_REENTRANT
+                                                                ) if activation_checkpointing else (lambda module:
+                                                                                                    module)
+                    second_wrap_fn = (
+                        lambda module: checkpoint_wrapper(
+                            first_wrap_fn(module),  # type: ignore reportGeneralTypeIssues
+                            checkpoint_impl=CheckpointImpl.NO_REENTRANT,
+                            offload_to_cpu=True)) if activation_cpu_offload else first_wrap_fn
+                else:
+                    first_wrap_fn = checkpoint_wrapper if activation_checkpointing else (lambda module: module)
+                    second_wrap_fn = (
+                        lambda module: checkpoint_wrapper(
+                            first_wrap_fn(module),  # type: ignore reportGeneralTypeIssues
+                            offload_to_cpu=True)) if activation_cpu_offload else first_wrap_fn
 
                 # Choose which modules to activation checkpoint according to the following priority:
                 # If module has attribute `module._activation_checkpointing = ...`, always respect it
