@@ -14,6 +14,7 @@ import tarfile
 import tempfile
 import textwrap
 import warnings
+from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Union
 
 import torch
@@ -210,6 +211,7 @@ def load_checkpoint(
                 object_store=object_store,
                 progress_bar=progress_bar,
                 fsdp_sharded_state_dict_enabled=state.fsdp_sharded_state_dict_enabled,
+                deepspeed_sharded_checkpoint=is_model_deepspeed(state.model),
             )
             rng_state_dicts = _restore_checkpoint(
                 state,
@@ -241,13 +243,12 @@ def _get_node_checkpoint_download_folder(path: Optional[str]) -> str:
     return local_rank_zero_path
 
 
-def download_checkpoint(
-    path: str,
-    node_checkpoint_folder: str,
-    object_store: Optional[Union[ObjectStore, LoggerDestination]],
-    progress_bar: bool,
-    fsdp_sharded_state_dict_enabled: bool = False,
-) -> Tuple[str, Optional[str], bool]:
+def download_checkpoint(path: str,
+                        node_checkpoint_folder: str,
+                        object_store: Optional[Union[ObjectStore, LoggerDestination]],
+                        progress_bar: bool,
+                        fsdp_sharded_state_dict_enabled: bool = False,
+                        deepspeed_sharded_checkpoint: bool = False) -> Tuple[str, Optional[str], bool]:
     """Download the checkpoint stored at ``path``, potentially in ``object_store``, to ``node_checkpoint_folder``.
 
     Returns a tuple of  (``composer_states_filepath``, ``extracted_checkpoint_folder``, ``extracted_rank_n``).
@@ -275,10 +276,11 @@ def download_checkpoint(
         composer_states_filepath = (rank_n_checkpoint_filepath
                                     if fsdp_sharded_state_dict_enabled else rank_zero_checkpoint_filepath)
 
+    checkpoint_is_sharded = fsdp_sharded_state_dict_enabled or deepspeed_sharded_checkpoint
     try:
-        if ((fsdp_sharded_state_dict_enabled and dist.get_global_rank() == 0) or
-            (not fsdp_sharded_state_dict_enabled and dist.get_local_rank() == 0)):
-            # every NODE needs the GLOBAL rank zero checkpoint unless fsdp_sharded_state_dict_enabled.
+        if not checkpoint_is_sharded and dist.get_local_rank() == 0:
+            # if the checkpoint is not sharded, then local rank 0 on each node needs to download the
+            # global rank 0 checkpoint
             path = _format_path_with_rank_zero(path)
             get_file(destination=rank_zero_checkpoint_filepath,
                      path=path,
@@ -293,21 +295,19 @@ def download_checkpoint(
                     # the underlying issue is that the checkpoint file does not exist on the disk
                     # or could not be downloaded
                     raise RuntimeError(f'Checkpoint {path} does not exist')
-
-        if rank_zero_checkpoint_filepath != rank_n_checkpoint_filepath:
-            # every RANK needs ITS OWN checkpoint.
-            # But, the  global rank zero is a special case -- these files are the same!
-            assert dist.get_global_rank() != 0, 'invariant violation'
-
+        elif checkpoint_is_sharded:
+            # if the checkpoint is sharded, then every rank needs to download its own checkpoint
             try:
                 get_file(destination=rank_n_checkpoint_filepath,
                          path=_format_path_with_current_rank(path),
                          object_store=object_store,
                          progress_bar=progress_bar)
-            except FileNotFoundError:
-                # Allowing not-found errors to be ignored as sometimes there won't be rank-local checkpoints
-                # (e.g. when not using deepspeed nor using fsdp sharded checkpoints)
-                pass
+            except FileNotFoundError as e:
+                raise FileNotFoundError(
+                    (f'Checkpoint {_format_path_with_current_rank(path)} does not exist, '
+                     f'but is required for sharded checkpointing on rank {dist.get_global_rank()}. '
+                     'Please ensure that the checkpoint exists and your load_path was specified as a format string'
+                     'with the {rank} argument.')) from e
 
             if extracted_checkpoint_folder is not None:
                 try:
@@ -322,10 +322,22 @@ def download_checkpoint(
 
     finally:
         # Wait for all checkpoints on the node to finish downloading
+        # First we wait for the local rank 0 to finish its download. This prevents timeouts
+        # in cases where the local rank 0 is downloading a monolithic checkpoint, and so takes
+        # much longer than the other ranks, which have nothing to download
         # Putting the barrier in a finally so the rank will always block on the barrier,
         # even if it has an exception.
         # Any exception will be re-raised after the barrier passes. The launcher script
         # will detect the process crash and terminate the other ranks
+
+        signal_file_path = os.path.join(node_checkpoint_folder, '.local_rank0_completed')
+        if dist.get_local_rank() == 0:
+            with open(signal_file_path, 'wb') as f:
+                f.write(b'local_rank0_completed')
+        dist.local_rank_zero_download_and_wait(signal_file_path)
+        if dist.get_local_rank() == 0:
+            os.remove(signal_file_path)
+
         dist.barrier()
 
     return composer_states_filepath, extracted_checkpoint_folder, extracted_rank_n
@@ -399,6 +411,25 @@ def glob_filter(exclude_globs: List[str]) -> Callable[[Dict], None]:
     return filter_func
 
 
+def safe_torch_load(composer_states_filepath: Union[Path, str], map_location: str = 'cpu'):
+    """Load a torch checkpoint, catching errors due to backwards compatibility issues.
+
+    Args:
+        composer_states_filepath: The path to the checkpoint file.
+        map_location: The location to load the checkpoint to.
+    """
+    try:
+        state_dict = torch.load(composer_states_filepath, map_location=map_location)
+        return state_dict
+    except TypeError as e:
+        if 'Accuracy.__new__() missing 1 required positional argument' in str(e):
+            raise Exception('As of v0.10.0, torchmetrics introduces a new required argument to Accuracy which '
+                            'breaks backwards compatibility. Unfortunately, this means that older checkpoints '
+                            'cannot be loaded with the metrics. In order to successfully load this model, please '
+                            'pass `load_ignore_keys = ["state/train_metrics/*", "state/eval_metrics/*"]`.') from e
+        raise e
+
+
 def _restore_checkpoint(
     state: State,
     logger: Logger,
@@ -413,7 +444,7 @@ def _restore_checkpoint(
 ) -> Optional[List[Dict[str, Any]]]:
     """Restore a checkpoint into ``state`` and returns the rng state dicts (if ``load_weights_only`` is False)."""
     # Now, all ranks load the checkpoint that local rank zero downloaded
-    state_dict = torch.load(composer_states_filepath, map_location='cpu')
+    state_dict = safe_torch_load(composer_states_filepath)
     if ignore_keys:
         # Filter provided list of key paths
         if not callable(ignore_keys):
